<?php
/**
* Plugin Name: Restrict - Hide from RSS feed
* Plugin URI: https://restrict.io/
* Description: Prevent restricted posts from being listed in the RSS feed. If you do not hide posts from the RSS, they will still remain restricted but protected message will be shown instead of a content.
* Author: Restrict
* Author URI: https://restrict.io/
* Version: 0.1
* Text Domain: rsc
* Domain Path: languages

* Copyright 2020 Tickera (https://tickera.com/)
*/

if ( ! defined( 'ABSPATH' ) ) {
  exit;
}
add_filter('rsc_settings_store_fields', 'rsc_add_new_fields_for_rss', 10, 1);

function rsc_add_new_fields_for_rss($fields){
  $fields[] = array(
    'field_name' => 'restrict_hide_rss',
    'field_title' => __('Hide from RSS feed', 'rsc'),
    'field_type' => 'function',
    'function' => 'rsc_yes_no',
    'default_value' => 'no',
    'tooltip' => __('Prevent restricted posts from being listed in the RSS feed. If you do not hide posts from the RSS, they will still remain restricted but protected message will be shown instead of a content.', 'rsc'),
    'section' => 'rss'
  );

  return $fields;
}

add_filter('rc_settings_new_sections', 'rsc_add_new_admin_section_for_rss', 10, 1);

function rsc_add_new_admin_section_for_rss($sections){
  $sections['general'][] = array(
    'name' => 'rss',
    'title' => __('RSS', 'rsc'),
    'description' => '',
    'subtitle' => '',
    'header' => '',
    'footer' => '',
    'description' => '',
  );
  return $sections;
}

add_action( 'pre_get_posts', function( \WP_Query $query ) {
  if ( !$query->is_feed() ) {
    return; // this isn't a feed
  }

  $rsc_settings = get_option('rsc_settings');

  $restrict_hide_rss = isset($rsc_settings['restrict_hide_rss']) ? $rsc_settings['restrict_hide_rss'] : 'no';

  $args = array(
    'meta_query' => array(
      'relation' => 'AND',
      array(
        'key' => '_rsc_content_availability',
        'compare' => 'EXISTS'
      ),
      array(
        'key' => '_rsc_content_availability',
        'value' => 'everyone',
        'compare' => '!='
      )
    ),
    'fields' => 'ids',
    'posts_per_page' => -1
  );

  if($restrict_hide_rss == 'yes'){

    $restricted_post_ids = get_posts( $args );

    $query->set('post__not_in', $restricted_post_ids );
  }
}
);

?>
